@@ -716,6 +716,7 @@ int main(int argc, char *argv[]) {
   *xaudio = 0;
   *xvideo = 0;
   *xtext = 0;
+  basename = NULL;
   no[NOAUDIO] = 0;
   no[NOVIDEO] = 0;
   no[NOTEXT] = 0;
@@ -816,6 +817,15 @@ int main(int argc, char *argv[]) {
       return 1;
     }
   }
+  if (basename != NULL) {
+    char *strp;
+    strp = basename;
+    while (*strp) {
+      if (*strp == '/')
+        basename = &strp[1];
+      strp++;
+    }
+  }
   if (fdin == -1) {
     usage(argv[0]);
     exit(1);
